@@ -165,7 +165,7 @@ class LoadMaster(HttpClient):
         if not isinstance(services, list):
             services = [services]
         for service in services:
-            virt_serv = self.build_virtual_service(service)
+            virt_serv = self.build_virtual_service(service, response)
             virtual_services.append(virt_serv)
         return virtual_services
 
@@ -186,13 +186,54 @@ class LoadMaster(HttpClient):
         return virt_serv
 
     def get_all_objects(self):
-        virtual_services = self.get_virtual_services()
-        for service in virtual_services:
-            service.real_servers = service.get_real_servers()
+        # x variables are the object while x_data is the OrderedDict
+        global_real_servers_data = []
+        virtual_services = []
+        response = self._get("/listvs")
+        data = get_data(response)
+        virtual_services_data = data.get('VS', [])
+        if not isinstance(virtual_services_data, list):
+            virtual_services_data = [virtual_services_data]
+        # loop through all vss and gather real server objects
+        for service_data in virtual_services_data:
+            real_servers_data = service_data.get('Rs', [])
+            if not isinstance(real_servers_data, list):
+                real_servers_data = [real_servers_data]
+            global_real_servers_data.extend(real_servers_data)
+
+        # create vs and rs objects at this point
+        # loop through all vss and attach matching real server objects
+        for service_data in virtual_services_data:
+            virtual_service = self.build_virtual_service(service_data,
+                                                         response)
+            virtual_services.append(virtual_service)
+
+        rs_vs_indexes = [(rs['VSIndex'], rs)
+                         for rs in global_real_servers_data]
+        rs_vs_indexes = dict(rs_vs_indexes)
+
+        for vs in virtual_services:
+            if vs.index in rs_vs_indexes:
+                rs = vs.build_real_server(rs_vs_indexes[vs.index])
+                vs.real_servers.append(rs)
+            for subvs in vs.subvs_entries:
+                if subvs.index in rs_vs_indexes:
+                    rs = subvs.build_real_server(rs_vs_indexes[subvs.index])
+                    subvs.real_servers.append(rs)
+
         return virtual_services
 
-    def build_virtual_service(self, service):
-        """Create a VirtualService instance with standard defaults"""
+    def build_virtual_service(self, service, response=None):
+        """Create a VirtualService instance with populated with API parameters
+
+        :param service: OrderedDict populated with virtual service data
+        :param response: Optional response of a listvs call. This acts as a
+                         cache, if you want to create a lot of VirtualService
+                         objects in a row, such as with looping, you can call
+                         listvs and pass the response in each time and this
+                         will nullify the extra listvs calls.
+        :return: VirtualService object with populated attributes
+        """
         is_sub_vs = True if int(service.get('MasterVSID', 0)) != 0 else False
         if is_sub_vs:
             response = self._get("/showvs", {"vs": service.get('MasterVSID')})
@@ -203,7 +244,8 @@ class LoadMaster(HttpClient):
             virt_serv.subvs_data = subvs_data[service.get('Index')]
             virt_serv.subvs_data['parentvs'] = service.get('MasterVSID')
         else:
-            response = self._get("/listvs")
+            if response is None:
+                response = self._get("/listvs")
             data = get_data(response)
             virt_serv = VirtualService(self.access_info,
                                        service.get('VSAddress'),
@@ -457,6 +499,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self._is_sub_vs = is_sub_vs
         self.subvs_data = None
         self.subvs_entries = []
+        self.real_servers = []
         if not is_sub_vs:
             # Skip validation when it is a subvs as they do not have ip/port
             self.vs = ip_or_index
